@@ -44,8 +44,8 @@ KNOWN_KEYS = {"nelec", "spin", "hf_occ", "schedule", "maxiter",
               "davidson_max_iter", "davidson_soft_max_iter", "one_body_parallel_rule",
               "n_sub_sweeps", "complex_mps", "split_states", "trans_mps_to_complex",
               "use_general_spin", "trans_integral_to_spin_orbital", "store_wfn_spectra",
-              "tran_bra_range", "tran_ket_range", "mem_ratio", "min_mpo_mem", "qc_mpo_type",
-              "full_integral"}
+              "tran_bra_range", "tran_ket_range", "tran_triangular",
+              "mem_ratio", "min_mpo_mem", "qc_mpo_type", "full_integral"}
 
 REORDER_KEYS = {"noreorder", "fiedler", "reorder", "gaopt", "nofiedler",
                 "irrep_reorder"}
