@@ -1343,6 +1343,50 @@ template <typename FL> struct FCIDUMP {
     }
 };
 
+template <typename FL> struct MRCISFCIDUMP : FCIDUMP<FL> {
+    using FCIDUMP<FL>::params;
+    shared_ptr<FCIDUMP<FL>> prim_fcidump;
+    uint16_t n_inactive, n_virtual, n_active;
+    MRCISFCIDUMP(const shared_ptr<FCIDUMP<FL>> &fcidump, uint16_t n_inactive,
+                 uint16_t n_virtual)
+        : FCIDUMP<FL>(), prim_fcidump(fcidump), n_virtual(n_virtual),
+          n_active(fcidump->n_sites() - n_inactive - n_virtual) {
+        params = fcidump->params;
+    }
+    virtual ~MRCISFCIDUMP() = default;
+    // One-electron integral element (SU(2))
+    FL t(uint16_t i, uint16_t j) const override {
+        return prim_fcidump->t(i, j);
+    }
+    // One-electron integral element (SZ)
+    FL t(uint8_t s, uint16_t i, uint16_t j) const override {
+        return prim_fcidump->t(s, i, j);
+    }
+    // Two-electron integral element (SU(2))
+    FL v(uint16_t i, uint16_t j, uint16_t k, uint16_t l) const override {
+        const uint16_t nocc = n_inactive + n_active;
+        const int cnt = (i >= nocc) + (j >= nocc) + (k >= nocc) + (l >= nocc);
+        if (cnt <= 1 || (cnt == 2 && (i >= nocc) == (j >= nocc) ||
+                         (i >= nocc) == (l >= nocc)))
+            return prim_fcidump->v(i, j, k, l);
+        else
+            return 0;
+    }
+    // Two-electron integral element (SZ)
+    FL v(uint8_t sl, uint8_t sr, uint16_t i, uint16_t j, uint16_t k,
+         uint16_t l) const override {
+        const uint16_t nocc = n_inactive + n_active;
+        const int cnt = (i >= nocc) + (j >= nocc) + (k >= nocc) + (l >= nocc);
+        if (cnt <= 1 || (cnt == 2 && (i >= nocc) == (j >= nocc) ||
+                         (i >= nocc) == (l >= nocc)))
+            return prim_fcidump->v(sl, sr, i, j, k, l);
+        else
+            return 0;
+    }
+    FL e() const override { return prim_fcidump->e(); }
+    void deallocate() override {}
+};
+
 template <typename FL> struct SpinOrbitalFCIDUMP : FCIDUMP<FL> {
     using FCIDUMP<FL>::params;
     shared_ptr<FCIDUMP<FL>> prim_fcidump;
@@ -1361,6 +1405,7 @@ template <typename FL> struct SpinOrbitalFCIDUMP : FCIDUMP<FL> {
         }
         params["orbsym"] = ss.str();
     }
+    virtual ~SpinOrbitalFCIDUMP() = default;
     // One-electron integral element (SGF)
     FL t(uint16_t i, uint16_t j) const override {
         if ((i ^ j) & 1)
