@@ -20,6 +20,8 @@
 
 #include "../block2_core.hpp"
 
+template struct block2::SiteBasis<block2::SZ>;
+template struct block2::SiteBasis<block2::SU2>;
 template struct block2::Hamiltonian<block2::SZ, double>;
 template struct block2::Hamiltonian<block2::SU2, double>;
 template struct block2::DelayedSparseMatrix<
